#
# spec file for package xfce4-screenshooter
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2010 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define xfce_version 4.18.0
%define plugin screenshooter

Name:           xfce4-screenshooter
Version:        1.11.2
Release:        1.0.2.1.sr20250601
Summary:        Screenshot Tool for the Xfce Desktop
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://goodies.xfce.org/projects/applications/xfce4-screenshooter
Source0:        https://archive.xfce.org/src/apps/xfce4-screenshooter/1.11/%{name}-%{version}.tar.xz
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  help2man
BuildRequires:  meson >= 0.56.0
BuildRequires:  update-desktop-files
BuildRequires:  xfce4-dev-tools
BuildRequires:  pkgconfig(exo-2) >= %{xfce_version}
BuildRequires:  pkgconfig(gdk-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gdk-wayland-3.0) >= 3.24.0
BuildRequires:  pkgconfig(gdk-x11-3.0) >= 3.24.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.66.0
BuildRequires:  pkgconfig(gthread-2.0) >= 2.42.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfconf-0) >= %{xfce_version}
BuildRequires:  pkgconfig(pango) >= 1.44.0
BuildRequires:  pkgconfig(wayland-client) >= 1.20
BuildRequires:  pkgconfig(wayland-protocols) >= 1.20
BuildRequires:  pkgconfig(wayland-scanner) >= 1.20
BuildRequires:  pkgconfig(x11) >= 1.6.7
BuildRequires:  pkgconfig(xext) >= 1.0.0
BuildRequires:  pkgconfig(xfixes) >= 4.0.0
BuildRequires:  pkgconfig(xi) >= 1.7.8
Recommends:     %{name}-lang = %{version}-%{release}
# needs xfhelp4
Requires:       libxfce4ui-tools
Suggests:       xfce4-%{plugin}-plugin
Obsoletes:      xfce4-screenshooter-doc <= 1.8.1
Provides:       xfce4-screenshooter-doc = %{version}
Recommends:     curl
Recommends:     jq
Recommends:     zenity

%description
Xfce4 Screenshooter is a tool for taking screenshots, it can capture the entire
screen, the active window or a selected region. Screenshots may be taken with a
user-specified delay and the resulting images can be saved to a PNG file,
copied it to the clipboard, opened with another application, or uploaded to
ZimageZ, a free online image hosting service.

%package -n xfce4-%{plugin}-plugin
Summary:        Screenshot Plugin for the Xfce Panel
Group:          System/GUI/XFCE
Requires:       xfce4-panel >= %{xfce_version}
Requires:       xfce4-screenshooter = %{version}-%{release}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description -n xfce4-%{plugin}-plugin
This package contains the xfce4-screenshooter Xfce panel plugin.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libscreenshooterplugin.la

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.xml

%find_lang xfce4-screenshooter %{?no_lang_C}

%suse_update_desktop_file -r xfce4-screenshooter -G 'Screenshot Tool' Utility X-SuSE-DesktopUtility GTK

%fdupes %{buildroot}%{_datadir}

%files
%doc NEWS README.md TODO
%license COPYING
%{_bindir}/xfce4-screenshooter
%{_datadir}/icons/hicolor/*
%{_datadir}/applications/xfce4-screenshooter.desktop
%{_datadir}/metainfo/xfce4-screenshooter.appdata.xml
%{_mandir}/man1/xfce4-screenshooter.1*

%files -n xfce4-%{plugin}-plugin
%{_libdir}/xfce4/panel/plugins/libscreenshooterplugin.so
%{_datadir}/xfce4/panel/plugins/screenshooter.desktop

%files lang -f %{name}.lang

%changelog
* Wed Jun 18 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to 1.11.2
  * Fully free a GSList to fix a leak
  * Fix a string leak in screenshooter_get_filename_for_uri
  * Properly free a GdkPixbuf to fix a leak
  * meson-build: Fix manpage install dir
  * Improve selection background in black surfaces
  * Fix xfce_resource_save_location leak in main
  * Replace deprecated exo with libxfce4ui 4.21.0
  * Remove imgur upload custom action automatically
  * Fix build with autotools
  * Drop Imgur custom action
  * preferences: Add link to the documentation for custom actions
    examples
  * Add support to Meson
  * Update xfce4-screenshooter.1
  * Fix segfault in another location
  * Fix segfault when app command is NULL (#132)
  * Improved imgur upload script
  * Add support to WL_SHM_FORMAT_BGR888
  * Check if file was correctly open before using it
  * Revert "Only restrict file permissions after sucessfully
    writing them"
  * Fix blurred preview images at scale >1
  * Only restrict file permissions after sucessfully writing them
  * Translation Updates
- Remove obsolete xfce4-screenshooter-relax-x11-version.patch
- Remove all bcond_with git code.
* Tue Jul 30 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to 1.11.1
  * Drop unnecessary libxml dependency
  * Translation Updates
* Fri Jul 26 2024 Manfred Hollstein <manfred.h@gmx.net>
- Add BuildRequires to enable Wayland support.
* Thu Jul 25 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to 1.11.0
  * Drop built-in support for imgur
  * Drop jobs-related code
  * Drop libsoup dependency
  * Use XDG_DATA_HOME in imgur-upload.sh
  * Make sure screenshot is copied to clipboard before closing (!56)
  * Add more tests
  * build: clang: Silence -Wcast-align
  * Translation Updates
* Wed May 29 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to 1.10.6
  * build: Switch from intltool to gettext
  * Preliminary Wayland support
  * Translation Updates
- Add xfce4-screenshooter-relax-x11-version.patch
* Mon Feb  5 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to 1.10.5
  * Add imgur support as custom action (!51)
  * Translation Updates
- Recommend curl, jq and zenity for the new script imgur.sh
* Wed May 17 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 1.10.4
  * Fix warning about checking file permissions
  * Refactor supported image formats handling (!49)
  * Add support to AVIF (#109)
  * Add support to JPEG XL (#108)
  * Check if the pixbuf-loader supports writing
  * Restrict file permission if not saved in a user-owned directory (#2)
  * Save preferences when plugin finalizes screenshot (#96)
  * Fix screenshot finalize behavior for plugin
  * Translation Updates
* Fri Jan 13 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 1.10.3
  * Lower minimal Xfce dependencies back to 4.16
  * Remove fallback code
* Thu Jan  5 2023 Dirk Müller <dmueller@suse.com>
- update to 1.10.2:
  * Fix capture of CSD windows
  * Fix active window and region capture modes
  * Consider scale factor while capturing screenshots with cairo
  * Support libsoup2 and 3 simultaneously
  * save dialog: show preview of selected file
  * Save preferences of panel plugin
  * Translation Updates
* Fri Dec 23 2022 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 1.10.1:
  * Fixes capture of screenshots after first time (gxo#apps/xfce4-screenshoter#89)
  * libsoup: Migrate to 3.0 (gxo#apps/xfce4-screenshoter#88)
  * Fix typo in NEWS file
  * Translation Updates
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- Update to version 1.10.0:
  * Bump requirements for Xfce 4.18
  * Introduce custom actions
  * Replace deprecated functions
  * Added writability check to screenshot_dir
  * Include "config.h" before GLib include files
  * Revert icon name translation
  * Drop subtitles
  * Add version check for libxi
  * Translation Updates
* Fri Aug 12 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.11
  * Add support to WebP (gxo#apps/xfce4-screenshooter#76)
  * Fix window capture in HiDPI mode (gxo#apps/xfce4-screenshooter#73)
  * Fix intltool lock file problem during make distcheck
  * Add option to Show in File Manager when saving
    (gxo#apps/xfce4-screenshooter#47)
  * Do not quit after dismissing dialog if invoked from plugin
    (gxo#apps/xfce4-screenshooter#71)
  * Update COPYING (gxo#apps/xfce4-screenshooter#70)
  * Translation Updates
* Sun Mar 13 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.10
  * Use symbolic icons
  * Bump Xfce dependencies to 4.14
  * _NET_FRAME_EXTENTS support
  * Add back button to take new screenshot
    (gxo#apps/xfce4-screenshooter!29)
  * Fix Imgur upload via CLI (gxo#apps/xfce4-screenshooter!26)
  * Set up ScreenshotData after commandline parsing
  * Fix compile warning (#62)
  * Update to description and addition of donate and translate links
  * Replace link to bugzilla with gitlab
    (gxo#apps/xfce4-screenshooter!25)
  * Translation Updates
* Thu May 20 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.9
  * Add link to Imgur ToS (gxo#apps/xfce4-screenshooter#54)
  * Add notice about imgur (gxo#apps/xfce4-screenshooter#53)
  * Add launchable tag to appdata.xml
  * Update help message for --save option
  * Add combobox with file extensions
    (gxo#apps/xfce4-screenshooter#6)
  * Add option to capture window border or not
    (gxo#apps/xfce4-screenshooter#4)
  * Preserve last used extension
  * Save screenshots according to the extension
    (gxo#apps/xfce4-screenshooter#6)
  * Avoid save dialog loop if action was specified from CLI
    (gxo#apps/xfce4-screenshooter#41)
  * Respect windows scaling (gxo#apps/xfce4-screenshoote!18)
  * Fix compilation warnings
  * Add version check for pango
  * Correctly calculate dimensions of size window
    (gxo#apps/xfce4-screenshooter#37)
  * Add option to disable Imgur upload
    (gxo#apps/xfce4-screenshooter#20)
  * Translation Updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.9.8
  - Fix dialog icons and add title to error dialog
  - Go back to actions dialog if image upload fails (#12)
  - Go back to actions dialog if GtkFileChooser is dismissed (#33)
  - Make radio buttons execute actions on enter/space press
  - Exclude shadow borders from CSD windows (!10)
  - Capture mouse cursor in rectangle selection (#30)
  - Region size should show updated size (!9)
  - Add info about Ctrl to "Select region" tooltip
  - Replace AC_CONFIG_MACRO_DIR with AC_CONFIG_MACRO_DIRS (!4)
  - Added 24px and 32px icons
  - Fix screenshot capture when scale > 1
  - Add new App icon and switch to rDNS icon name
  - Switch to README.md and foreign automake mode
  - bxo#16717: Move from exo-csource to xdt-csource
  - Update homepage link at appdata.xml
  - Translation Updates
* Mon Nov  4 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.7
  * Add warning notice to imgur upload option (bxo#15347)
  * Fix cursor capture when near screen edge (bxo#9262)
  * Improve wording (bxo#15429)
  * Allow compilation with panel 4.15
  * Restore libxfce4ui 4.12 compatibility
  * Translation Updates
* Mon Aug 26 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.9.6
  * Do not show translation info on --help output (bxo#15883)
  * Avoid destroying size window twice (bxo#15792)
  * Replace GtkStock buttons
  * Add missing NULL as last parameter of
    xfce_titled_dialog_new_with_buttons() (bxo#14973)
  * Do not use root coordinates for region capture (bxo#15406)
  * Install AppData into metainfo
  * Update AppData file
  * Try to grab seat more than once (bxo#15320)
  * Use new xfce_gdk_screen_get_geometry if available
  * Make screenshooter-imgur-dialog.ui translatable (bxo#15254)
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Thu Aug 15 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Renamed Panel Plugin subpackage to follow upstream naming
  xfce4-foo-plugin
- Added bcond for git master builds
* Sat Mar 30 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 1.9.5
  * Bug fixed:
  - Panel plugin: allow it to save files (bxo#15187)
* Tue Mar 19 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Switched URL and Source to https:// in the spec file.
* Mon Mar 18 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.9.4
  * Enhancements:
  - Extended save function to also take files (bxo#14156)
  - Show width and height of selection area (bxo#12664)
  - Improved imgur dialog (bxo#14973)
  - Don't save region/delay/show_mouse if region was specified from CLI
  * Bugs fixed:
  - React to core X input events when XInput is not available (bxo#15166)
  - Fix crash and properly handle cursors on HiDPI
  - Delay in panel plugin does not work (bxo#14604)
- Dropped obsolete macros
* Sun Aug 12 2018 seife+obs@b1-systems.com
- update to version 1.9.3
  - Allow user to move selection rectangle (bxo#14365)
  - Allow and remember 0sec delay for all regions (bxo#13763)
  - Fix clipboard action handling (bxo#14513)
* Tue May 15 2018 seife+obs@b1-systems.com
- update to version 1.9.2
  - Remove zimagez support (bxo#14283)
  - Use g_app_info_launch() for command launching (bxo#13886)
  - Dismiss the progress dialog after upload (bxo#12519)
  - Improve thumbnail size clamping
  - Allow --clipboard option to be used with the others (bxo#14120)
  - Handle device grab failure (bxo#10259)
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to version 1.9.1
  - Fix crash on program exit after image upload (bxo#13415)
- version 1.9.0
  - Use HTTPS for imgur (bxo#13415)
- version 1.8.99
  - Port to GTK+3
  - Fix appdata description
  - Fix crash in GValueArray handling (bxo#11879)
  - Use while instead of when in strings (bxo#12157)
  - Fix gray overlay in region mode screenshots (bxo#11922)
  - Fix crash when uploading to zimagez (bxo#11879)
- Updated translations
* Tue Jan 27 2015 gber@opensuse.org
- update to version 1.8.2
  - Enhancements:
  - Add imgur.com as possible upload option (bxo#6899)
  - Add appdate file (bxo#11202)
  - Make region selection with compositing on more usable on
    darker backgrounds (bxo#9592)
  - Updated translations
  - Bugs fixed:
  - Fix keyboard navigation between choices (bxo#11325)
  - Fix build with automake 1.13 (bxo#10030)
  - Use filename-friendly date format for saved files (bxo#8445)
  - drop obsolete xfce4-screenshooter-fix-plugin-linking.patch
    xfce4-screenshooter-use-docdir.patch,
    xfce4-screenshooter-automake-1.13.patch,
    xfce4-screenshooter-automake-1.14.patch
  - drop -doc subpackage, documentation has been removed
* Thu Oct 16 2014 dimstar@opensuse.org
- Add xfce4-screenshooter-automake-1.14.patch: Fully intialize
  before doing furher actions. Works around an issue with AM 1.14.
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Mon May  7 2012 gber@opensuse.org
- fix xfce4-screenshooter-fix-plugin-linking.patch so the panel
  plugin is linked against libscreenshooter
- fix help function by depending on libxfce4ui-tools which provides
  xfhelp4 again
* Thu May  3 2012 gber@opensuse.org
- update to version 1.8.1
  - adapting the panel plugin to xfce4-panel 4.9+
  - add a clipboard CLI option
  - panel plugin is now built as a library
  - fix crash with some window managers
  - fix crash with NULL save path
  - install documentation to new location
  - add explicit -lm link to LIBADD
  - plugin installation location compatible with xfce4-panel 4.9+
  - update outdated man page
- rebased xfce4-screenshooter-1.8.0-use-docdir.patch as
  xfce4-screenshooter-use-docdir.patch
- added xfce4-screenshooter-fix-plugin-linking.patch in order to
  link the plugin module correctly
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- added xfce4-screenshooter-fix-crash-with-some-wms.patch which
  fixes a crash when taking a screenshot of a window with some
  window managers (bxo#8080)
- correct dependencies
* Wed Mar 14 2012 gber@opensuse.org
- recommend -lang subpackage
* Fri Oct 21 2011 gber@opensuse.org
- added xfce4-screenshooter-1.8.0-use-docdir.patch in order to
  allow installation of documentation under docdir
- install HTML documentation under
  /usr/share/xfce4/xfce4-screenshooter/html
* Fri Oct 14 2011 gber@opensuse.org
- recommend -doc subpackage
* Mon Sep 19 2011 gber@opensuse.org
- added xfce4-screenshooter-fix-libm-underlinking.patch in order to
  explicitly link against libm
* Mon Aug  1 2011 gber@opensuse.org
- update to version 1.8.0
  - capture the cursor using XFIXES
  - generate valid BBCode
  - further bugfixes and translation updates
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
* Thu Feb  3 2011 gber@opensuse.org
- build documentation
* Thu Feb  3 2011 gber@opensuse.org
- update to current git snapshot (1.7.9.99_git20110203)
  - port to current exo
  - port from libxfcegui4 to libxfce4ui
  - many bugfixes
  - translation updates
- dropped obsolete xfce4-screenshooter-1.7.9-fix-crash.patch and
  xfce4-screenshooter-1.7.9-use-system-exo.patch
* Mon Dec 27 2010 gber@opensuse.org
- correct group and URL
* Sun Dec  5 2010 gber@opensuse.org
- Initial packaging
